@@ -54,7 +54,7 @@ from keystoneclient import access
 from keystoneclient.auth import base
 from keystoneclient import baseclient
 from keystoneclient import exceptions
-from keystoneclient.i18n import _, _LW
+from keystoneclient.i18n import _
 from keystoneclient import session as client_session
 
 
@@ -131,7 +131,7 @@ class _KeystoneAdapter(adapter.LegacyJsonAdapter):
             # return None
             pass
 
-        # there is a case that we explicity allow (tested by our unit tests)
+        # there is a case that we explicitly allow (tested by our unit tests)
         # that says you should be able to set the user_id on a legacy client
         # and it should overwrite the one retrieved via authentication. If it's
         # a legacy then self.session.auth is a client and we retrieve user_id.
@@ -393,7 +393,7 @@ class HTTPClient(baseclient.Client, base.BaseAuthPlugin):
 
         # keyring setup
         if use_keyring and keyring is None:
-            _logger.warning(_LW('Failed to load keyring modules.'))
+            _logger.warning('Failed to load keyring modules.')
         self.use_keyring = use_keyring and keyring is not None
         self.force_new_token = force_new_token
         self.stale_duration = stale_duration or access.STALE_TOKEN_DURATION
@@ -442,7 +442,10 @@ class HTTPClient(baseclient.Client, base.BaseAuthPlugin):
     @property
     def service_catalog(self):
         """Return this client's service catalog."""
-        return self.auth_ref.service_catalog
+        try:
+            return self.auth_ref.service_catalog
+        except AttributeError:
+            return None
 
     def has_service_catalog(self):
         """Return True if this client provides a service catalog."""
@@ -630,8 +633,7 @@ class HTTPClient(baseclient.Client, base.BaseAuthPlugin):
                         auth_ref = None
             except Exception as e:
                 auth_ref = None
-                _logger.warning(
-                    _LW('Unable to retrieve token from keyring %s'), e)
+                _logger.warning('Unable to retrieve token from keyring %s', e)
         return (keyring_key, auth_ref)
 
     def store_auth_ref_into_keyring(self, keyring_key):
@@ -643,8 +645,7 @@ class HTTPClient(baseclient.Client, base.BaseAuthPlugin):
                                      pickle.dumps(self.auth_ref))  # nosec
                 # (cjschaef): see bug 1534288
             except Exception as e:
-                _logger.warning(
-                    _LW("Failed to store token into keyring %s"), e)
+                _logger.warning("Failed to store token into keyring %s", e)
 
     def _process_management_url(self, region_name):
         try:
