@@ -13,6 +13,7 @@
 import copy
 import uuid
 
+from keystoneauth1 import exceptions
 from keystoneauth1 import fixture
 from keystoneauth1.identity import v3
 from keystoneauth1 import session
@@ -21,7 +22,6 @@ import six
 from testtools import matchers
 
 from keystoneclient import access
-from keystoneclient import exceptions
 from keystoneclient.tests.unit.v3 import utils
 from keystoneclient.v3 import client
 from keystoneclient.v3.contrib.federation import base
